<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
</context>
<context>
    <name>NotificationWindow</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
